pub struct Simple(/* private fields */);Expand description
A CBOR simple value.
The simple values false, true, null and undefined (20 to 23) map
onto the deser data model (undefined is deserialized as null). All
other simple values are unassigned and passed through deser as extension
atoms of this type. Their fallback is an unsigned integer.
use deser_cbor::Simple;
let bytes = deser_cbor::to_vec(&Simple::new(16).unwrap()).unwrap();
assert_eq!(bytes, [0xf0]);
let value: Simple = deser_cbor::from_slice(&bytes).unwrap();
assert_eq!(value.value(), 16);Implementations