StreamDeserializer

Struct StreamDeserializer 

pub struct StreamDeserializer { /* private fields */ }
Reads a stream of CBOR data items into items (see deser::stream).

The stream is a CBOR sequence of data items that follow each other. An item is complete once its last byte was read. Reading continues after items that fail to deserialize, items that are not well-formed end the stream.

Items which do not borrow are deserialized while their input arrives (see StreamDeserializer::drive_partial) so only incomplete data items (like strings) are buffered.

use deser_cbor::DeserializerConfig;

let mut reader =
    DeserializerConfig::new().reader(&[0x01, 0x62, b'h', b'i'][..]);
assert_eq!(reader.read::<u32>().unwrap(), Some(1));
assert_eq!(reader.read::<String>().unwrap().as_deref(), Some("hi"));
assert_eq!(reader.read::<u32>().unwrap(), None);

Items are parsed like with a Deserializer, so they can borrow from the stream’s buffer (see InputBuffer::deserialize).

Implementations

Source

impl StreamDeserializer

pub fn new() -> StreamDeserializer

Creates a stream deserializer.

pub fn with_config(config: DeserializerConfig) -> StreamDeserializer

Creates a stream deserializer with the given configuration.

pub fn config(&self) -> &DeserializerConfig

Returns the configuration.