Simple

Struct Simple 

pub struct Simple(/* private fields */);
A CBOR simple value.

The simple values false, true, null and undefined (20 to 23) map onto the deser data model (undefined is deserialized as null). All other simple values are unassigned and passed through deser as extension atoms of this type. Their fallback is an unsigned integer.

use deser_cbor::Simple;

let bytes = deser_cbor::to_vec(&Simple::new(16).unwrap()).unwrap();
assert_eq!(bytes, [0xf0]);
let value: Simple = deser_cbor::from_slice(&bytes).unwrap();
assert_eq!(value.value(), 16);

Implementations

Source

impl Simple

pub fn new(value: u8) -> Option<Simple>

Creates a simple value.

Returns None for the reserved values 24 to 31 which have no valid encoding.

pub fn value(self) -> u8

Returns the numeric value.