pub struct Tagged<T> {
pub tag: Option<u64>,
pub value: T,
}Expand description
A value with an optional CBOR tag.
When serialized the tag is written in front of the value, when
deserialized the tag (if there is one) is captured. If the value has
multiple tags, the outermost tag is captured and the inner tags are left
for the value (so Tagged<Tagged<T>> captures two tags).
use deser_cbor::Tagged;
// 1(1363896240): an epoch based date/time
let bytes = deser_cbor::to_vec(&Tagged::new(1, 1363896240u64)).unwrap();
assert_eq!(bytes, [0xc1, 0x1a, 0x51, 0x4b, 0x67, 0xb0]);
let value: Tagged<u64> = deser_cbor::from_slice(&bytes).unwrap();
assert_eq!(value.tag, Some(1));
assert_eq!(value.value, 1363896240);Other formats do not support tags. When serializing to such formats the
tag is dropped, when deserializing the tag is None.
Fields
tag: Option<u64>The tag of the value.
value: TThe value.
Implementations